@@ -6,7 +6,8 @@ use JS::jQuery::Loader::Carp;
 
 sub new {
     my $class = shift;
-    my $uri = "http://jqueryjs.googlecode.com/files/\%j";
+#    my $uri = "http://jqueryjs.googlecode.com/files/\%j";
+    my $uri = "http://ajax.googleapis.com/ajax/libs/jquery/\%v/jquery\%.f.js";
     return JS::jQuery::Loader::Source::URI->new(uri => $uri, @_);
 }
 
